@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.58 2006/09/08 17:58:08 bowkenken Exp $
+* $Id: amenu.c,v 1.60 2006/09/20 05:23:23 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1978,7 +1978,7 @@ char	*cb_menu_auto_mark_appoint_item_mnr(
 * return : ˥塼ΰư
 ***************************************************************/
 
-char	*cb_menu_auto_mark_macro( menu_t **pp, menu_t **dflt )
+char	*cb_menu_auto_mark_edit_macro_bind( menu_t **pp, menu_t **dflt )
 {
 	char	*cmd;
 	static char	msg_cmd[WIN_MSG_DRAW_WIDTH + 1];
@@ -1988,11 +1988,11 @@ char	*cb_menu_auto_mark_macro( menu_t **pp, menu_t **dflt )
 	/* Υޥɽ */
 
 	cmd = ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].macro;
-	print_msg( FLG_NULL, MSG_GETS_AUTO_MARK_MACRO_TTL, cmd );
+	print_msg( FLG_NULL, MSG_GETS_AUTO_MARK_EDIT_MACRO_TTL, cmd );
 
 	/* ץץȤɽ */
 
-	sprintf( msg_cmd, MSG_GETS_AUTO_MARK_MACRO_CMD, MACRO_MAX_LEN );
+	sprintf( msg_cmd, MSG_GETS_AUTO_MARK_EDIT_MACRO_CMD, MACRO_MAX_LEN );
 	print_msg( FLG_NULL, msg_cmd );
 
 	/* ޥ桼 */
@@ -2020,8 +2020,53 @@ char	*cb_menu_auto_mark_macro( menu_t **pp, menu_t **dflt )
 
 	/* ޥ */
 
-	str_nz_cpy( ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].macro,
-			buf_cmd, MACRO_MAX_LEN );
+	str_nz_cpy( cmd, buf_cmd, MACRO_MAX_LEN );
+
+	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_EDIT_MACRO_DONE, cmd );
+
+	return STR_MENU_CANCEL;
+}
+
+/***************************************************************
+* Խ˥塼Υޥ
+* menu_t **pp : ˥塼
+* menu_t **dflt : ˥塼Υǥե
+* return : ˥塼ΰư
+***************************************************************/
+
+char	*cb_menu_auto_mark_edit_macro_reg_macro(
+	menu_t **pp, menu_t **dflt
+)
+{
+	char	*cmd, *reg_cmd;
+	char	*msg;
+	ask_t	ask;
+
+	/* Υޥɽ */
+
+	cmd = ls_auto_mark[g_sel_mbr->ls_mbr_n][auto_mark_cur_n].macro;
+	print_msg( FLG_NULL, MSG_GETS_AUTO_MARK_EDIT_MACRO_TTL, cmd );
+
+	/* ǧ */
+
+	msg = MSG_TTL_MENU_AUTO_MARK_EDIT_MACRO_REG_MACRO;
+	print_msg( FLG_NULL, msg );
+
+	ask = exec_menu_ask( msg, ASK_NO, TRUE );
+	if( ask == ASK_ERR )
+		return STR_MENU_ERR;
+	if( ask != ASK_YES )
+		return STR_MENU_CANCEL;
+
+	/* ޥ */
+
+	reg_cmd = get_reg_macro();
+	if( reg_cmd == NULL )
+		return STR_MENU_CANCEL;
+
+	str_nz_cpy( cmd, reg_cmd, MACRO_MAX_LEN );
+
+	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_EDIT_MACRO_DONE, cmd );
 
 	return STR_MENU_CANCEL;
 }
