@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.102 2006/09/10 23:53:46 bowkenken Exp $
+* $Id: chr.h,v 1.103 2006/09/19 02:30:57 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -792,9 +792,9 @@ typedef struct chr_t {
 	modifier_t	modifier_fx;
 
 	/* 󥹥μ */
-	mnstr_kind_t	mnstr_kind;
+	mnstr_kind_t	mnstr_kind, mnstr_kind_org;
 	/* 󥹥ǡơ֥ */
-	mnstr_tab_t	*mnstr_tab;
+	mnstr_tab_t	*mnstr_tab, *mnstr_tab_org;
 
 	/* ¾ */
 	chr_work_t	work;
