@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: curs.c,v 1.66 2006/08/10 21:33:18 bowkenken Exp $
+* $Id: curs.c,v 1.67 2006/09/20 01:10:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -698,7 +698,9 @@ void	curs_move( int scrn_y, int scrn_x )
 
 		scrn_pos.X = scrn_x;
 		scrn_pos.Y = scrn_y;
-		SetConsoleCursorPosition( GetStdHandle( STD_OUTPUT_HANDLE ), scrn_pos );
+		SetConsoleCursorPosition(
+				GetStdHandle( STD_OUTPUT_HANDLE ),
+				scrn_pos );
 		return;
 	}
 #endif	/* D_DOS */
