@@ -32,6 +32,7 @@ bool_t	set_msg_mul_line( bool_t flg );
 bool_t	chk_msg_mul_line( void );
 long	get_ls_msg_n( void );
 void	draw_ls_msg( long n );
+ls_msg_t	*get_ls_msg( long idx );
 void	print_str( long scrn_x, long scrn_y, const char *s, ... );
 bool_t	set_redraw_every_turn( bool_t flg );
 bool_t	chk_redraw_every_turn( void );
@@ -133,6 +134,9 @@ bool_t	chk_flg_break_key( void );
 long	read_char( long *p );
 long	read_char_wait( long *p );
 long	read_esc( long *p );
+char	*get_reg_macro( void );
+void	set_reg_macro( bool_t flg );
+void	reg_macro( long c );
 long	get_key( bool_t flg_clr_key_buf );
 long	get_key_sub( bool_t flg_clr_key_buf );
 long	get_key_x68k( bool_t flg_clr_key_buf );
