@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.50 2006/09/11 22:59:24 bowkenken Exp $
+* $Id: draw.h,v 1.51 2006/09/23 19:06:21 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -149,12 +149,21 @@ typedef unsigned long	flg_msg_t;
 /* ³Ԥ̵ */
 #define	FLG_MSG_NO_MORE	(FLG_MSG_NO_MORE_PREV | FLG_MSG_NO_MORE_NEXT)
 
+/***************************************************************
+* åꥹ
+***************************************************************/
+
 /* åꥹȤɽԿ */
 #define	LS_MSG_DRAW_N	20
 
 /* åκԿ */
 #define	LS_MSG_MAX_N	(LS_MSG_DRAW_N * 8)
 
+typedef struct {
+	char	msg[SCREEN_WIDTH * 2 + 1];
+	curs_attr_t	attr;
+} ls_msg_t;
+
 /***************************************************************
 * ե졼ࡦ졼
 ***************************************************************/
