@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.94 2006/02/04 08:11:47 bowkenken Exp $
+* $Id: dun.c,v 1.96 2006/09/19 04:35:15 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -237,6 +237,8 @@ void	reset_dun( bool_t flg_wall )
 
 			dun.map.light_depth_obj[y][x] = 0;
 			dun.map.light_depth_chr[y][x] = 0;
+
+			dun.map.chr_p[y][x] = NULL;
 		}
 	}
 
@@ -2286,6 +2288,7 @@ void	set_map_total_chr( long x, long y, long dx, long dy )
 	long	xx, yy;
 	char	mjr, mnr;
 	flg_map_t	flg, flg_total;
+	chr_t	*chr_p;
 	curs_attr_n_t	attr_n;
 	curs_attr_t	*attr_dflt;
 
@@ -2307,12 +2310,15 @@ void	set_map_total_chr( long x, long y, long dx, long dy )
 			mjr = dun.map.chr.mjr[yy][xx];
 			mnr = dun.map.chr.mnr[yy][xx];
 			flg = dun.map.chr.flg[yy][xx];
+			chr_p = dun.map.chr_p[yy][xx];
 			attr_n = CURS_ATTR_N_NORMAL;
 			flg_rev_rev = FALSE;
 
 			if( mjr == FACE_MJR_NULL ){
 				continue;
-			} else if( mjr == FACE_MJR_MBR ){
+			} else if( chr_p == NULL ){
+				continue;
+			} else if( chr_p->kind == CHR_KIND_MBR ){
 				mbr_t	*p;
 
 				/* Сä */
@@ -2326,7 +2332,7 @@ void	set_map_total_chr( long x, long y, long dx, long dy )
 					/* Ʃʤ */
 					flg_rev_rev = TRUE;
 				}
-			} else {
+			} else if( chr_p->kind == CHR_KIND_MNSTR ){
 				/* 󥹥ä */
 				if( !chk_flg( flg, FLG_MAP_CHR_FIND ) ){
 					/* ĤäƤʤ */
@@ -2337,6 +2343,8 @@ void	set_map_total_chr( long x, long y, long dx, long dy )
 				} else {
 					attr_n = CURS_ATTR_N_MAP_MNSTR;
 				}
+			} else {
+				continue;
 			}
 
 			dun.map.total.mjr[yy][xx] = mjr;
@@ -3034,6 +3042,16 @@ dun_t	*get_dun( void )
 	return &dun;
 }
 
+/***************************************************************
+* µܤθߤγؤ֤
+* return : ߤγ
+***************************************************************/
+
+long	get_dun_lev( void )
+{
+	return dun.lev;
+}
+
 /***************************************************************
 * ɸˤɥΥǡ֤
 * long x : Xɸ
