@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.117 2006/08/10 21:33:18 bowkenken Exp $
+* $Id: fight.c,v 1.120 2006/09/17 14:35:51 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -809,7 +809,9 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 	bool_t	flg_auto_hit;
 	bool_t	flg_serious;
 	bool_t	flg_err_range;
+	bool_t	flg_catch_food;
 	char	mjr;
+	item_t	arw;
 
 	if( attack == NULL )
 		return FALSE;
@@ -846,6 +848,9 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 	/* ꤲʪ̵ʤä饭󥻥 */
 
 	eq = NULL;
+	arw.kind = ITEM_KIND_NULL;
+	arw.prev = NULL;
+	arw.next = NULL;
 	if( attack->flg_throw && (o_k == CHR_KIND_MBR) ){
 		eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
 		if( eq[EQUIP_KIND_ARW].kind == ITEM_KIND_NULL ){
@@ -855,6 +860,9 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 
 			return FALSE;
 		}
+
+		copy_item( &arw, &(eq[EQUIP_KIND_ARW]) );
+		arw.n = 1;
 	}
 
 	/* ΥΥå */
@@ -878,6 +886,15 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 	if( cancel_fx_vanish( o_p ) )
 		return FALSE;
 
+	/* ʪä? */
+
+	if( eq == NULL ){
+		flg_catch_food = FALSE;
+	} else {
+		flg_catch_food = chk_mnstr_catch_food(
+				d_p, &(eq[EQUIP_KIND_ARW]) );
+	}
+
 	/* ø */
 
 	flg_serious = TRUE;
@@ -887,6 +904,8 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 				/* ̣ɤʤø */
 				flg_serious = FALSE;
 			}
+		} else if( flg_catch_food ){
+			flg_serious = FALSE;
 		} else {
 			set_enemy_mnstr_group( o_p, d_p );
 		}
@@ -1036,6 +1055,13 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 		o_dam *= 2;
 	}
 
+	/* ʪ */
+
+	if( flg_catch_food ){
+		o_hit = 2;
+		d_def = 1;
+	}
+
 	print_msg( FLG_MSG_DEBUG, "o_hit: %ld, d_def: %ld",
 			o_hit, d_def );
 
@@ -1114,9 +1140,16 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 
 	/* ݡä */
 
-	if( (eq != NULL) && (eq[EQUIP_KIND_ARW].kind == ITEM_KIND_POTION) )
+	if( (eq != NULL) && (arw.kind == ITEM_KIND_POTION) )
 		o_dam = 0;
 
+	/* ʪä */
+
+	if( flg_catch_food ){
+		fx_mnstr_catch_food( d_p, &arw );
+		return TRUE;
+	}
+
 	/* ⤬ä */
 
 	/* ᡼ɽ */
@@ -1155,10 +1188,10 @@ bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack, long range )
 
 	/* ݡä */
 
-	if( (eq != NULL) && (eq[EQUIP_KIND_ARW].kind == ITEM_KIND_POTION) ){
+	if( (eq != NULL) && (arw.kind == ITEM_KIND_POTION) ){
 		o_dam = 0;
 
-		quaff_potion( (chr_t *)d_p, &(eq[EQUIP_KIND_ARW]), FALSE );
+		quaff_potion( (chr_t *)d_p, &arw, FALSE );
 	}
 
 	/*  */
@@ -1305,19 +1338,6 @@ bool_t	spell_attack(
 		return FALSE;
 	}
 
-	/* ᡼ */
-
-	if( flg_stick )
-		dam = get_dam_stick( o_p );
-	else
-		dam = get_dam_spell( o_p, abl, get_sub_abl( abl ) );
-	dam = dam * rate / _100_PERCENT;
-	dam = roll_dice( dam, TRUE );
-
-	/* ޡ饹 */
-
-	ac = get_ac( d_p );
-
 	/* и */
 
 	if( flg_stick ){
@@ -1326,8 +1346,19 @@ bool_t	spell_attack(
 		vfx_arw( o_p->kind, &o_pos, &d_pos, mjr, ANIM_ARW_LEN );
 	}
 
+	/* ޡ饹 */
+
+	ac = get_ac( d_p );
+
 	/* ᡼η׻ */
 
+	if( flg_stick )
+		dam = get_dam_stick( o_p );
+	else
+		dam = get_dam_spell( o_p, abl, get_sub_abl( abl ) );
+	dam = dam * rate / _100_PERCENT;
+	dam = roll_dice( dam, TRUE );
+
 	dam = calc_resi( get_resi_def( d_p, resi ), dam );
 	dam -= ac;
 	if( dam < 1 )
@@ -2181,7 +2212,7 @@ long	get_dam_stick( chr_t *p )
 		return 1;
 
 	abl_main = get_specialist_abl( p );
-	abl_sub = get_specialist_abl( p );
+	abl_sub = abl_main;
 
 	dam = 0;
 	dam += calc_lev_to_val( get_lev( p, abl_main ), abl_main );
