@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fx.h,v 1.48 2006/02/17 04:45:36 bowkenken Exp $
+* $Id: fx.h,v 1.51 2006/09/19 02:30:57 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	FX_H
@@ -38,79 +38,12 @@
 #include	"abl-kind.h"
 
 /***************************************************************
-* եȤθ̤ζ
-***************************************************************/
-
-#define	RESURRECTION_MIN_RATE	30
-#define	RESURRECTION_MAX_RATE	90
-
-#define	MAGIC_SHIELD_ADD_DEF_RATE	50
-#define	MAGIC_SHIELD_MAX_N	1
-
-#define	MAGE_ARMOR_ADD_AC_RATE	20
-#define	MAGE_ARMOR_MAX_N	3
-
-#define	SUBSTITUTE_ADD_DEF_RATE	20
-#define	SUBSTITUTE_ADD_AC_RATE	20
-#define	SUBSTITUTE_MAX_N	2
-
-#define	BURNING_HANDS_ADD_HIT_RATE	20
-#define	BURNING_HANDS_ADD_DAM_RATE	20
-#define	BURNING_HANDS_MAX_N	2
-
-#define	MIND_READING_ADD_WPN_CRTCL_RATE	20
-#define	MIND_READING_ADD_ARMOR_CRTCL_RATE	20
-#define	MIND_READING_MAX_N	2
-
-/***************************************************************
-* եȤʿѻ³
+* եȤλ³
 ***************************************************************/
 
 /* Ⱦʵ */
 #define	FX_TURN_INFINITE_N	(-1)
 
-/* Ǥǲ HP 뤫? */
-#define	FX_AVE_TURN_POISON_DEC	20
-
-#define	FX_AVE_TURN_STONE	FX_TURN_INFINITE_N
-#define	FX_AVE_TURN_PARALYZE	16
-#define	FX_AVE_TURN_POISON	1024
-#define	FX_AVE_TURN_CONFUSION	16
-#define	FX_AVE_TURN_BLIND	512
-#define	FX_AVE_TURN_SLEEP	32
-#define	FX_AVE_TURN_SILENCE	32
-#define	FX_AVE_TURN_FEAR	32
-#define	FX_AVE_TURN_HALLUCINATION	32
-#define	FX_AVE_TURN_CHARM	32
-#define	FX_AVE_TURN_FLY	128
-#define	FX_AVE_TURN_VANISH	128
-#define	FX_AVE_TURN_IRON_BODY	32
-#define	FX_AVE_TURN_PASSWALL	128
-#define	FX_AVE_TURN_SENSE_INVISIBLE	128
-
-#define	FX_AVE_TURN_MAGIC_SHIELD	64
-#define	FX_AVE_TURN_MAGE_ARMOR	64
-#define	FX_AVE_TURN_SUBSTITUTE	32
-#define	FX_AVE_TURN_BURNING_HANDS	32
-#define	FX_AVE_TURN_MIND_READING	32
-
-#define	FX_AVE_TURN_POW_UP_HP	64
-#define	FX_AVE_TURN_POW_UP_ABL	64
-#define	FX_AVE_TURN_POW_DOWN_ABL	64
-#define	FX_AVE_TURN_POW_UP_RESI	64
-#define	FX_AVE_TURN_SPEED_UP	256
-#define	FX_AVE_TURN_SPEED_DOWN	256
-
-#define	FX_AVE_TURN_STORE_LIGHT	FX_TURN_INFINITE_N
-
-#define	FX_AVE_TURN_DARKVISION	128
-#define	FX_AVE_TURN_RECALL	20
-
-#define	FX_AVE_TURN_BLESS	64
-
-#define	FX_AVE_TURN_FAINT	16
-#define	FX_TURN_DRUNK	1024
-
 /***************************************************************
 * եȤμ
 ***************************************************************/
@@ -133,6 +66,7 @@ typedef enum {
 	FX_KIND_VANISH,
 	FX_KIND_IRON_BODY,
 	FX_KIND_PASSWALL,
+	FX_KIND_POLYMORPH,
 	FX_KIND_SENSE_INVISIBLE,
 	FX_KIND_WEAK_HEAT,
 	FX_KIND_WEAK_COLD,
@@ -164,6 +98,7 @@ typedef enum {
 	FX_KIND_POW_UP_HP,
 	FX_KIND_MAGIC_SHIELD,
 	FX_KIND_MAGE_ARMOR,
+	FX_KIND_COUNTER_MAGIC,
 	FX_KIND_SUBSTITUTE,
 	FX_KIND_BURNING_HANDS,
 	FX_KIND_MIND_READING,
