@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.14 2006/02/17 04:45:36 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.16 2006/09/19 05:41:03 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
@@ -1672,6 +1672,8 @@ fx_kind_t	g_fx_trans_tab[] = {
 	FX_KIND_SPEED_DOWN,
 	FX_KIND_BLESS,
 	FX_KIND_STORE_LIGHT,
+	FX_KIND_COUNTER_MAGIC,
+	FX_KIND_POLYMORPH,
 };
 
 /***************************************************************
