@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu-tab.h,v 1.2 2006/08/09 18:05:15 bowkenken Exp $
+* $Id: imenu-tab.h,v 1.3 2006/09/20 03:16:36 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	IMENU_TAB_H
@@ -573,13 +573,13 @@ menu_t	ls_menu_color_sel[] = {
 menu_t	ls_menu_crsr_ptn[1 + 1 + CRSR_PTN_MAX_N + 1];
 menu_t	ls_menu_user[
 	1 + 1
-	+ USER_MENU_MAX_N
-	+ (USER_MENU_MAX_N / MENU_MAX_N_PER_PAGE)
-	+ 3 + 1];
+	+ (1 * USER_MENU_MAX_N)
+	+ (2 * USER_MENU_MAX_N / MENU_MAX_N_PER_PAGE)
+	+ 5 + 1];
 menu_t	ls_menu_user_edit[
 	1 + 1
-	+ USER_MENU_MAX_N
-	+ (USER_MENU_MAX_N / MENU_MAX_N_PER_PAGE)
-	+ 3 + 1];
+	+ (1 * USER_MENU_MAX_N)
+	+ (2 * USER_MENU_MAX_N / MENU_MAX_N_PER_PAGE)
+	+ 5 + 1];
 
 #endif	/* IMENU_TAB_H */
