@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.12 2006/09/12 01:25:21 bowkenken Exp $
+* $Id: imenu.c,v 1.18 2006/09/26 18:12:20 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -886,7 +886,7 @@ char	*menu_mbr_give_gold( mbr_t *mbr_from )
 
 			n = 0;
 			max = get_chr_gold( mbr_from );
-			str = exec_menu_sel_num( 0, max, &n );
+			str = exec_menu_sel_num( &n, 0, max );
 
 			if( str == NULL ){
 				/* Ϥ */
@@ -2895,7 +2895,7 @@ char	*cb_menu_vfx_wait( menu_t **pp, menu_t **dflt )
 
 	n = get_vfx_wait();
 
-	ret = exec_menu_sel_num( VFX_WAIT_MIN_N, VFX_WAIT_MAX_N, &n );
+	ret = exec_menu_sel_num( &n, VFX_WAIT_MIN_N, VFX_WAIT_MAX_N );
 	if( ret == NULL ){
 		set_vfx_wait( n );
 		sprintf( (*pp)->msg, MSG_MENU_VFX_WAIT, n );
@@ -3383,8 +3383,51 @@ char	*cb_menu_set_key( menu_t **pp, menu_t **dflt )
 
 	set_key_tab( buf_key, buf_cmd );
 
-	print_msg( FLG_MSG_DEBUG, "set key '%s' \"%s\"",
-			buf_key, buf_cmd );
+	print_msg( FLG_NULL, MSG_MENU_SET_KEY_DONE, buf_key, buf_cmd );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_set_key_reg_macro( menu_t **pp, menu_t **dflt )
+{
+	char	*msg_key = MSG_GETS_SET_KEY_KEY;
+	static char	buf_key[MACRO_MAX_LEN + 1];
+	char	*cmd;
+	long	x, y;
+
+	/* key */
+
+	print_msg( FLG_NULL, msg_key );
+
+	x = str_len_draw( msg_key );
+	y = get_max_line() - 1;
+	if( game_gets( x, y, buf_key, MACRO_MAX_LEN, TRUE ) ){
+		long	len;
+
+		len = str_len_std( buf_key );
+		if( len >= 1 )
+			if( buf_key[len - 1] == '\n' )
+				buf_key[len - 1] = '\0';
+
+		if( buf_key[0] == '\0' )
+			return STR_MENU_CANCEL;
+	} else {
+		return STR_MENU_CANCEL;
+	}
+
+	/* command */
+
+	cmd = get_reg_macro();
+	if( cmd == NULL )
+		return STR_MENU_CANCEL;
+
+	/**/
+
+	set_key_tab( buf_key, cmd );
+
+	print_msg( FLG_NULL, MSG_MENU_SET_KEY_DONE, buf_key, cmd );
 
 	return STR_MENU_CANCEL;
 }
@@ -3428,9 +3471,9 @@ char	*cb_menu_unset_key( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_macro( menu_t **pp, menu_t **dflt )
+char	*cb_menu_func( menu_t **pp, menu_t **dflt )
 {
-	*pp = get_ls_menu_macro();
+	*pp = get_ls_menu_func();
 	*dflt = NULL;
 
 	return NULL;
@@ -3438,45 +3481,79 @@ char	*cb_menu_macro( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*cb_menu_macro_exec( menu_t **pp, menu_t **dflt )
+char	*cb_menu_func_exec( menu_t **pp, menu_t **dflt )
 {
 	long	n;
 
 	n = (long)((*pp)->arg);
-	set_key_buf_str( get_macro( n ) );
+	set_key_buf_str( get_func( n ) );
 
 	return NULL;
 }
 
 /**/
 
-char	*cb_menu_macro_edit( menu_t **pp, menu_t **dflt )
+char	*cb_menu_func_edit( menu_t **pp, menu_t **dflt )
 {
-	char	*msg = MSG_GETS_MACRO_EDIT;
+	char	*msg = MSG_GETS_FUNC_EDIT;
 	static char	buf[MACRO_MAX_LEN + 1];
 	long	n;
 	long	x, y;
+	long	len;
 
 	x = str_len_draw( msg );
 	y = get_max_line() - 1;
 	n = (long)((*pp)->arg);
 
-	print_msg( FLG_NULL, MSG_GETS_MACRO_PREV, get_macro( n ) );
+	print_msg( FLG_NULL, MSG_GETS_FUNC_PREV, get_func( n ) );
 	print_msg( FLG_NULL, msg, MACRO_MAX_LEN );
 
-	if( game_gets( x, y, buf, MACRO_MAX_LEN, TRUE ) ){
-		long	len;
+	if( !game_gets( x, y, buf, MACRO_MAX_LEN, TRUE ) )
+		return STR_MENU_CANCEL;
 
-		len = str_len_std( buf );
-		if( len >= 1 )
-			if( buf[len - 1] == '\n' )
-				buf[len - 1] = '\0';
+	len = str_len_std( buf );
+	if( len >= 1 )
+		if( buf[len - 1] == '\n' )
+			buf[len - 1] = '\0';
+	if( buf[0] == '\0' )
+		return STR_MENU_CANCEL;
 
-		if( buf[0] != '\0' )
-			str_nz_cpy( get_macro( n ), buf, MACRO_MAX_LEN );
-	}
-	print_msg( FLG_MSG_DEBUG, "set macro[%ld]: \"%s\"",
-			n, get_macro( n ) );
+	str_nz_cpy( get_func( n ), buf, MACRO_MAX_LEN );
+
+	print_msg( FLG_NULL, MSG_MENU_FUNC_KEY_DONE, n, get_func( n ) );
+
+	return STR_MENU_CANCEL;
+}
+
+/**/
+
+char	*cb_menu_func_set_reg_macro( menu_t **pp, menu_t **dflt )
+{
+	static char	msg[WIN_MSG_DRAW_WIDTH + 1];
+	long	n;
+	char	*cmd;
+	ask_t	ask;
+
+	n = (long)((*pp)->arg);
+
+	sprintf( msg, MSG_TTL_MENU_FUNC_SET_REG_MACRO, n );
+
+	print_msg( FLG_NULL, MSG_GETS_FUNC_PREV, get_func( n ) );
+	print_msg( FLG_NULL, msg );
+
+	ask = exec_menu_ask( msg, ASK_NO, TRUE );
+	if( ask == ASK_ERR )
+		return STR_MENU_ERR;
+	if( ask != ASK_YES )
+		return STR_MENU_CANCEL;
+
+	cmd = get_reg_macro();
+	if( cmd == NULL )
+		return STR_MENU_CANCEL;
+
+	str_nz_cpy( get_func( n ), cmd, MACRO_MAX_LEN );
+
+	print_msg( FLG_NULL, MSG_MENU_FUNC_KEY_DONE, n, get_func( n ) );
 
 	return STR_MENU_CANCEL;
 }
@@ -3556,7 +3633,7 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 			MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<OpenWinItem>",
 			MENU_KIND_MAX_LEN );
-	ls[k].accel_key = 'W';
+	ls[k].accel_key = 'V';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
 	str_nz_cpy( ls[k].msg, MSG_MENU_USER_NEW, MENU_MSG_MAX_LEN );
@@ -3565,6 +3642,20 @@ char	*cb_menu_user( menu_t **pp, menu_t **dflt )
 	ls[k].flg = FLG_NULL;
 	k++;
 
+	str_nz_cpy( ls[k].path, "/user menu/new reg macro",
+			MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].kind, "<OpenWinItem>",
+			MENU_KIND_MAX_LEN );
+	ls[k].accel_key = 'W';
+	ls[k].short_key[0] = '\0';
+	ls[k].n_msg = N_MSG_NULL;
+	str_nz_cpy( ls[k].msg, MSG_MENU_USER_NEW_REG_MACRO,
+			MENU_MSG_MAX_LEN );
+	ls[k].call_back = cb_menu_user_new_reg_macro;
+	ls[k].arg = NULL;
+	ls[k].flg = FLG_NULL;
+	k++;
+
 	str_nz_cpy( ls[k].path, "/user menu/arrange top",
 			MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<Branch>",
@@ -3673,6 +3764,22 @@ char	*cb_menu_user_sel( menu_t **pp, menu_t **dflt )
 /**/
 
 char	*cb_menu_user_new( menu_t **pp, menu_t **dflt )
+{
+	return menu_user_new_sub( pp, dflt, FALSE );
+}
+
+/**/
+
+char	*cb_menu_user_new_reg_macro( menu_t **pp, menu_t **dflt )
+{
+	return menu_user_new_sub( pp, dflt, TRUE );
+}
+
+/**/
+
+char	*menu_user_new_sub(
+	menu_t **pp, menu_t **dflt, bool_t flg_reg_macro
+)
 {
 	char	*msg_name = MSG_GETS_USER_MENU_NAME;
 	static char	msg_cmd[WIN_MSG_DRAW_WIDTH + 1];
@@ -3702,31 +3809,40 @@ char	*cb_menu_user_new( menu_t **pp, menu_t **dflt )
 
 	/* command */
 
-	sprintf( msg_cmd, MSG_GETS_USER_MENU_CMD, MACRO_MAX_LEN );
-	print_msg( FLG_NULL, msg_cmd );
+	if( flg_reg_macro ){
+		char	*macro = get_reg_macro();
 
-	x = str_len_draw( msg_cmd );
-	y = get_max_line() - 1;
-	if( game_gets( x, y, buf_cmd, MACRO_MAX_LEN, TRUE ) ){
-		long	len;
-
-		len = str_len_std( buf_cmd );
-		if( len >= 1 )
-			if( buf_cmd[len - 1] == '\n' )
-				buf_cmd[len - 1] = '\0';
-
-		if( buf_cmd[0] == '\0' )
+		if( macro == NULL )
 			return STR_MENU_CANCEL;
+
+		str_nz_cpy( buf_cmd, macro, MACRO_MAX_LEN );
 	} else {
-		return STR_MENU_CANCEL;
+		sprintf( msg_cmd, MSG_GETS_USER_MENU_CMD, MACRO_MAX_LEN );
+		print_msg( FLG_NULL, MSG_S, msg_cmd );
+
+		x = str_len_draw( msg_cmd );
+		y = get_max_line() - 1;
+		if( game_gets( x, y, buf_cmd, MACRO_MAX_LEN, TRUE ) ){
+			long	len;
+
+			len = str_len_std( buf_cmd );
+			if( len >= 1 )
+				if( buf_cmd[len - 1] == '\n' )
+					buf_cmd[len - 1] = '\0';
+
+			if( buf_cmd[0] == '\0' )
+				return STR_MENU_CANCEL;
+		} else {
+			return STR_MENU_CANCEL;
+		}
 	}
 
 	/**/
 
 	add_user_menu( buf_name, buf_cmd );
 
-	print_msg( FLG_MSG_DEBUG, "set user menu '%s' \"%s\"",
-			buf_name, buf_cmd );
+	print_msg( FLG_NULL, MSG_MENU_USER_NEW_DONE_1, buf_name );
+	print_msg( FLG_NULL, MSG_MENU_USER_NEW_DONE_2, buf_cmd );
 
 	return "/misc/config/user menu select";
 }
@@ -3987,7 +4103,7 @@ char	*cb_menu_wizard_add_turn( menu_t **pp, menu_t **dflt )
 	static long	turn = 0;
 	char	*str;
 
-	str = exec_menu_sel_num( -n, +n, &turn );
+	str = exec_menu_sel_num( &turn, -n, +n );
 	if( str != NULL )
 		return str;
 
@@ -4009,7 +4125,7 @@ char	*cb_menu_wizard_lev_up( menu_t **pp, menu_t **dflt )
 	char	*str;
 	long	i;
 
-	str = exec_menu_sel_num( -n, +n, &exp );
+	str = exec_menu_sel_num( &exp, -n, +n );
 	if( str != NULL )
 		return str;
 
