@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.22 2006/09/15 09:38:44 bowkenken Exp $
+* $Id: inc.h,v 1.24 2006/09/26 18:12:20 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -1160,7 +1160,7 @@
 #include	"gmain.h"
 #include	"misc.h"
 /*#include	"turn.h"*/
-/*#include	"dun.h"*/
+#include	"dun.h"
 /*#include	"town.h"*/
 #include	"item.h"
 /*#include	"spell.h"*/
@@ -1182,7 +1182,7 @@
 #include	"gmain-prot.h"
 #include	"misc-prot.h"
 /*#include	"turn-prot.h"*/
-/*#include	"dun-prot.h"*/
+#include	"dun-prot.h"
 /*#include	"town-prot.h"*/
 /*#include	"item-prot.h"*/
 /*#include	"spell-prot.h"*/
@@ -1756,6 +1756,128 @@
 
 /***************************************************************/
 
+#ifdef	GUI_MESSAGE_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"draw.h"
+#include	"curs.h"
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+#include	"gmain-prot.h"
+/*#include	"misc-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+#include	"draw-prot.h"
+#include	"curs-prot.h"
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_WS
+#endif // D_WS
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include "GuiMisc.h"
+#endif // D_GTK
+
+#endif	/* GUI_MESSAGE_CPP */
+
+/***************************************************************/
+
+#ifdef	GUI_NUM_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+#include	"misc-prot.h"
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_WS
+#endif // D_WS
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include "GuiMisc.h"
+#endif // D_GTK
+
+#endif	/* GUI_NUM_CPP */
+
+/***************************************************************/
+
 #if	defined( D_WIN )
 # include	"main-win-prot.h"
 #elif	defined( D_DOS )
