@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dos.c,v 1.9 2006/09/06 23:04:23 bowkenken Exp $
+* $Id: main-dos.c,v 1.10 2006/09/26 18:12:20 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -261,7 +261,7 @@ bool_t	chk_opt_flg( const char *optarg )
 * ǻꤵ줿
 ***************************************************************/
 
-void	overwrite_arg()
+void	overwrite_arg( void )
 {
 	if( g_flg_clr_key_buf_arg_overwrite ){
 		g_flg_clr_key_buf = g_flg_clr_key_buf_arg;
