@@ -7,7 +7,7 @@ extern "C" {
 int	main( int argc, char **argv );
 void	chk_arg( int argc, char **argv );
 bool_t	chk_opt_flg( const char *optarg );
-void	overwrite_arg();
+void	overwrite_arg( void );
 void	usage( FILE *fp );
 void	child_ps_unix( void );
 void	init_term_unix( void );
