@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: menu.c,v 1.183 2006/09/06 23:04:23 bowkenken Exp $
+* $Id: menu.c,v 1.186 2006/09/26 18:12:20 bowkenken Exp $
 ***************************************************************/
 
 #define	MENU_C
@@ -72,15 +72,15 @@ static char	*menu_kind_ls[] = {
 	NULL,
 };
 
-static char	g_macro[FUNC_KEY_MAX_N + 1][MACRO_MAX_LEN + 1];
+static char	g_func[FUNC_KEY_MAX_N + 1][MACRO_MAX_LEN + 1];
 
 typedef struct {
 	char	*key;
 	char	*dflt;
-} macro_short_key_t;
+} func_short_key_t;
 
-static macro_short_key_t
-		g_ls_macro_short_key[FUNC_KEY_MAX_N + 1] = {
+static func_short_key_t
+		g_ls_func_short_key[FUNC_KEY_MAX_N + 1] = {
 	{ NULL, NULL },	/* NULL */
 	{ NULL, NULL },	/* F1 */
 	{ NULL, NULL },	/* F2 */
@@ -120,29 +120,29 @@ void	init_menu( void )
 	chk_dup_short_key();
 
 	for( i = 1; i <= FUNC_KEY_MAX_N; i++ ){
-		g_macro[i][0] = '\0';
+		g_func[i][0] = '\0';
 
-		if( g_ls_macro_short_key[i].dflt != NULL ){
-			str_nz_cpy( g_macro[i],
-					g_ls_macro_short_key[i].dflt,
+		if( g_ls_func_short_key[i].dflt != NULL ){
+			str_nz_cpy( g_func[i],
+					g_ls_func_short_key[i].dflt,
 					MACRO_MAX_LEN );
 		}
 	}
 
-	init_ls_menu_macro();
+	init_ls_menu_func();
 }
 
 /**/
 
-void	init_ls_menu_macro( void )
+void	init_ls_menu_func( void )
 {
 	menu_t	*ls;
 	long	i, k;
 
-	ls = ls_menu_macro;
+	ls = ls_menu_func;
 	k = 0;
 
-	str_nz_cpy( ls[k].path, "/macro", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/func", MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
@@ -152,18 +152,18 @@ void	init_ls_menu_macro( void )
 	ls[k].flg = FLG_NULL;
 	k++;
 
-	str_nz_cpy( ls[k].path, "/macro/--", MENU_PATH_MAX_LEN );
+	str_nz_cpy( ls[k].path, "/func/--", MENU_PATH_MAX_LEN );
 	str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
-	str_nz_cpy( ls[k].msg, MSG_MENU_MACRO, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_FUNC, MENU_MSG_MAX_LEN );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
 	k++;
 
 	for( i = 1; i <= FUNC_KEY_MAX_N; i++ ){
-		sprintf( ls[k].path, "/macro/%ld", i );
+		sprintf( ls[k].path, "/func/%ld", i );
 		str_nz_cpy( ls[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = (char)('A' + (i - 1));
 		ls[k].short_key[0] = '\0';
@@ -173,7 +173,7 @@ void	init_ls_menu_macro( void )
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/macro/%ld/--", i );
+		sprintf( ls[k].path, "/func/%ld/--", i );
 		str_nz_cpy( ls[k].kind, "<Title>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = '\0';
 		ls[k].short_key[0] = '\0';
@@ -183,27 +183,38 @@ void	init_ls_menu_macro( void )
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/macro/%ld/exec", i );
+		sprintf( ls[k].path, "/func/%ld/exec", i );
 		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'X';
-		if( g_ls_macro_short_key[i].key == NULL ){
+		if( g_ls_func_short_key[i].key == NULL ){
 			sprintf( ls[k].short_key, "&%02ld", i );
 		} else {
 			sprintf( ls[k].short_key, "%s &%02ld",
-					g_ls_macro_short_key[i].key, i );
+					g_ls_func_short_key[i].key, i );
 		}
-		str_nz_cpy( ls[k].msg, MSG_MENU_MACRO_EXEC, MENU_MSG_MAX_LEN );
-		ls[k].call_back = cb_menu_macro_exec;
+		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_EXEC, MENU_MSG_MAX_LEN );
+		ls[k].call_back = cb_menu_func_exec;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
 		k++;
 
-		sprintf( ls[k].path, "/macro/%ld/edit", i );
+		sprintf( ls[k].path, "/func/%ld/edit", i );
 		str_nz_cpy( ls[k].kind, "<OpenWinItem>", MENU_KIND_MAX_LEN );
 		ls[k].accel_key = 'E';
 		ls[k].short_key[0] = '\0';
-		str_nz_cpy( ls[k].msg, MSG_MENU_MACRO_EDIT, MENU_MSG_MAX_LEN );
-		ls[k].call_back = cb_menu_macro_edit;
+		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_EDIT, MENU_MSG_MAX_LEN );
+		ls[k].call_back = cb_menu_func_edit;
+		ls[k].arg = (void *)i;
+		ls[k].flg = FLG_NULL;
+		k++;
+
+		sprintf( ls[k].path, "/func/%ld/set reg macro", i );
+		str_nz_cpy( ls[k].kind, "<Item>", MENU_KIND_MAX_LEN );
+		ls[k].accel_key = 'M';
+		ls[k].short_key[0] = '\0';
+		str_nz_cpy( ls[k].msg, MSG_MENU_FUNC_SET_REG_MACRO,
+				MENU_MSG_MAX_LEN );
+		ls[k].call_back = cb_menu_func_set_reg_macro;
 		ls[k].arg = (void *)i;
 		ls[k].flg = FLG_NULL;
 		k++;
@@ -475,13 +486,21 @@ char	*cb_menu_ask_no( menu_t **pp, menu_t **dflt )
 
 /**/
 
-char	*exec_menu_sel_num( long min, long max, long *p )
+char	*exec_menu_sel_num( long *p, long min, long max )
 {
-	long	i;
+	long	n;
+	long	gui_n;
 	long	figure;
 	long	sel_n;
 	char	num[FIGURE_MAX_N];
 	const char	*fmt = "%+0*ld";
+	long	i;
+
+	if( p == NULL )
+		return STR_MENU_ERR;
+
+	n = *p;
+	gui_n = n;
 
 	figure = 0;
 	if( labs( min ) < labs( max ) )
@@ -493,20 +512,25 @@ char	*exec_menu_sel_num( long min, long max, long *p )
 	if( figure < 1 )
 		figure = 1;
 
-	sprintf( num, fmt, (int)(figure + 1), *p );
+	sprintf( num, fmt, (int)(figure + 1), n );
 
 	sel_n = 1 + figure + MENU_NUM_OK;
 	while( 1 ){
 		long	d;
 		bool_t	flg_ret;
 
+		if( g_flg_gui )
+			call_gui_num_draw( &gui_n, min, max, figure );
 		draw_menu_num( figure, sel_n, num );
 
 		d = 0;
 		flg_ret = FALSE;
 
+		n = strtol( num, (char **)NULL, 10 );
+
 		switch( get_key( g_flg_clr_key_buf_menu ) ){
 		case CASE_CANCEL:
+			call_gui_num_wipe();
 			return STR_MENU_CANCEL;
 		case ' ':
 			if( g_flg_space_select ){
@@ -537,55 +561,63 @@ char	*exec_menu_sel_num( long min, long max, long *p )
 			if( sel_n > 1 + figure + MENU_NUM_MAX_N - 1 )
 				sel_n = 0;
 			break;
+		case '|':
+			n = gui_n;
+			sel_n = 1 + figure + MENU_NUM_OK;
+			flg_ret = TRUE;
+			break;
 		default:
 			break;
 		}
 
-		*p = strtol( num, (char **)NULL, 10 );
-
 		if( (d != 0) || flg_ret ){
 			if( sel_n == 1 + figure + MENU_NUM_OK ){
 				if( flg_ret ){
-					if( *p < min )
-						*p = min;
-					else if( *p > max )
-						*p = max;
-					else
+					if( n < min ){
+						n = min;
+					} else if( n > max ){
+						n = max;
+					} else {
+						*p = n;
+						call_gui_num_wipe();
 						return NULL;
+					}
+					gui_n = n;
 				}
 			} else if( sel_n == 1 + figure + MENU_NUM_MIN ){
 				if( flg_ret )
-					*p = min;
+					n = min;
 			} else if( sel_n == 1 + figure + MENU_NUM_MAX ){
 				if( flg_ret )
-					*p = max;
+					n = max;
 			} else if( sel_n == 1 + figure + MENU_NUM_CLR ){
 				if( flg_ret )
-					*p = 0;
+					n = *p;
 			} else if( sel_n == 0 ){
 				if( num[0] == '-' )
 					num[0] = '+';
 				else
 					num[0] = '-';
 
-				*p = strtol( num, (char **)NULL, 10 );
+				n = strtol( num, (char **)NULL, 10 );
 			} else {
-				long	n;
+				long	m;
 
-				n = num[sel_n] - '0' + d;
-				if( n > 9 )
-					n = 0;
-				if( n < 0 )
-					n = 9;
-				num[sel_n] = (char)('0' + n);
+				m = num[sel_n] - '0' + d;
+				if( m > 9 )
+					m = 0;
+				if( m < 0 )
+					m = 9;
+				num[sel_n] = (char)('0' + m);
 
-				*p = strtol( num, (char **)NULL, 10 );
+				n = strtol( num, (char **)NULL, 10 );
 			}
 
-			sprintf( num, fmt, (int)(figure + 1), *p );
+			sprintf( num, fmt, (int)(figure + 1), n );
 		}
 	}
 
+	call_gui_num_wipe();
 	return STR_MENU_ERR;
 }
 
@@ -1145,7 +1177,7 @@ long	chk_key( bool_t flg_clr_key_buf, bool_t flg_chk_menu )
 				wipe_menu();
 				break;
 			}
-			if( chk_short_key( get_ls_menu_macro(), c ) ){
+			if( chk_short_key( get_ls_menu_func(), c ) ){
 				wipe_menu();
 				break;
 			}
@@ -1340,21 +1372,21 @@ bool_t	chk_short_key( menu_t *ls, long c )
 
 /**/
 
-menu_t	*get_ls_menu_macro( void )
+menu_t	*get_ls_menu_func( void )
 {
-	return ls_menu_macro;
+	return ls_menu_func;
 }
 
 /**/
 
-char	*get_macro( long n )
+char	*get_func( long n )
 {
 	if( n < 0 )
 		n = 0;
 	if( n >= FUNC_KEY_MAX_N )
 		n = 0;
 
-	return g_macro[n];
+	return g_func[n];
 }
 
 /**/
