@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu-tab.h,v 1.12 2006/09/11 22:59:25 bowkenken Exp $
+* $Id: mmenu-tab.h,v 1.14 2006/09/20 02:03:40 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	MMENU_TAB_H
@@ -961,12 +961,21 @@ menu_t	ls_menu_main[] = {
 	{
 		"/misc/config/key/key bind/set key",
 		"<OpenWinItem>",
-		'A',
+		'B',
 		"",
 		N_MSG_MENU_SET_KEY, "",
 		cb_menu_set_key, NULL,
 		FLG_NULL,
 	},
+	{
+		"/misc/config/key/key bind/set key reg macro",
+		"<OpenWinItem>",
+		'M',
+		"",
+		N_MSG_MENU_SET_KEY_REG_MACRO, "",
+		cb_menu_set_key_reg_macro, NULL,
+		FLG_NULL,
+	},
 	{
 		"/misc/config/key/key bind/unset key",
 		"<OpenWinItem>",
@@ -977,12 +986,12 @@ menu_t	ls_menu_main[] = {
 		FLG_NULL,
 	},
 	{
-		"/misc/config/key/macro",
+		"/misc/config/key/func",
 		"<Branch>",
 		'F',
 		"",
-		N_MSG_MENU_MACRO, "",
-		cb_menu_macro, NULL,
+		N_MSG_MENU_FUNC, "",
+		cb_menu_func, NULL,
 		FLG_NULL,
 	},
 	{
