@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.12 2006/09/06 23:04:23 bowkenken Exp $
+* $Id: mmenu.c,v 1.13 2006/09/26 18:12:20 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -1748,7 +1748,7 @@ char	*cb_menu_item_send( menu_t **pp, menu_t **dflt )
 
 	/* Ŀ */
 	n = g_sel_item->n;
-	str = exec_menu_sel_num( 1, n, &n );
+	str = exec_menu_sel_num( &n, 1, n );
 	if( str != NULL )
 		return str;
 
@@ -1788,7 +1788,7 @@ char	*cb_menu_item_receive( menu_t **pp, menu_t **dflt )
 
 	/* Ŀ */
 	n = g_sel_item->n;
-	str = exec_menu_sel_num( 1, n, &n );
+	str = exec_menu_sel_num( &n, 1, n );
 	if( str != NULL )
 		return str;
 
@@ -1819,7 +1819,7 @@ char	*cb_menu_item_drop( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 
 	n = g_sel_item->n;
-	str = exec_menu_sel_num( 1, g_sel_item->n, &n );
+	str = exec_menu_sel_num( &n, 1, g_sel_item->n );
 	if( str != NULL )
 		return str;
 
