@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.176 2006/09/12 00:45:09 bowkenken Exp $
+* $Id: mnstr.c,v 1.180 2006/09/19 04:35:15 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -270,7 +270,9 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->fx_data.bless = 0;
 
 	mnstr->mnstr_kind = MNSTR_KIND_NULL;
+	mnstr->mnstr_kind_org = MNSTR_KIND_NULL;
 	mnstr->mnstr_tab = NULL;
+	mnstr->mnstr_tab_org = NULL;
 
 	mnstr->work.flg = FLG_NULL;
 	mnstr->work.caught = 0;
@@ -460,7 +462,9 @@ mnstr_t	*make_mnstr_alloc(
 	p->fx.next = &(p->fx);
 	p->fx.prev = &(p->fx);
 	p->mnstr_kind = mnstr_kind;
+	p->mnstr_kind_org = mnstr_kind;
 	p->mnstr_tab = tab;
+	p->mnstr_tab_org = tab;
 
 	p->work.flg = FLG_NULL;
 	p->work.flg &= ~(FLG_WORK_FIND_MBR);
@@ -976,6 +980,9 @@ bool_t	mnstr_move_or_atack_std( mnstr_t *p )
 	sum_throw = calc_attack_sum( ls, FALSE, FALSE, TRUE, FALSE );
 	sum_spell = calc_attack_sum( ls, FALSE, FALSE, FALSE, TRUE );
 
+	if( !chk_can_chr_cast_stat( p ) )
+		sum_spell = 0;
+
 	n = randm( sum_bash + sum_throw + sum_spell );
 
 	if( n < sum_bash ){
@@ -1236,6 +1243,7 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 	long	i;
 	dun_t	*dun;
 	party_t	*pty;
+	bool_t	flg_pre_find;
 	long	bx, by;
 	long	ex, ey;
 	long	x, y;
@@ -1250,6 +1258,7 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 
 	/* ȯĴ٤ */
 
+	flg_pre_find = chk_flg( p->flg_map, FLG_MAP_CHR_FIND );
 	p->flg_map &= ~FLG_MAP_CHR_FIND;
 	for( i = 0; i < MBR_MAX_N; i++ ){
 
@@ -1259,10 +1268,16 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 			/* ȯޥåסե饰ΩƤ */
 			p->flg_map |= FLG_MAP_CHR_FIND;
 
+			break;
+		}
+	}
+
+	if( chk_flg( p->flg_map, FLG_MAP_CHR_FIND ) ){
+		if( flg_pre_find ){
+			return TRUE;
+		} else {
 			/* ɸå */
 			chk_find_request_chr( p );
-
-			break;
 		}
 	}
 
@@ -1586,13 +1601,11 @@ void	mnstr_drop_item( mnstr_t *p )
 void	set_find_all_mnstr( void )
 {
 	mnstr_t	*head, *p, *pp;
-	dun_t	*dun;
+	dun_t	*dun = get_dun();
 	long	bx, by;
 	long	ex, ey;
 	long	x, y;
 
-	dun = get_dun();
-
 	head = &mnstr_used;
 	for( p = head->next->next; p != NULL; p = p->next ){
 		pp = p->prev;
@@ -1623,24 +1636,13 @@ void	set_find_all_mnstr( void )
 
 void	print_ls_mnstr( void )
 {
-	party_t	*pty = get_party();
 	long	max_dun_lev_base, min_lev, max_lev;
 	long	i, max_i;
 
-	/* Сߤꤿֿ */
-
-	max_dun_lev_base = 0;
-	for( i = 0; i < MBR_MAX_N; i++ ){
-		long	lev;
-
-		lev = labs( pty->mbr[i]->dun_max_lev_base );
-		if( max_dun_lev_base < lev )
-			max_dun_lev_base = lev;
-	}
-
 	/* ߤγΤʤˤ */
 
-	max_dun_lev_base -= 1;
+	max_dun_lev_base = get_party_dun_max_lev();
+	max_dun_lev_base--;
 
 	/* 󥹥ΥꥹȤʤ */
 
@@ -1800,6 +1802,31 @@ mnstr_tab_t	*get_mnstr_tab( mnstr_kind_t mnstr_kind, long dun_lev )
 ***************************************************************/
 
 mnstr_tab_t	*get_mnstr_tab_rand( long dun_lev )
+{
+	return get_mnstr_tab_rand_sub( dun_lev, FALSE );
+}
+
+/***************************************************************
+* 󥹥Υǡơ֥˸(ػꤢ)
+* long dun_lev : 󥸥γ
+* return : 󥹥Υǡơ֥
+***************************************************************/
+
+mnstr_tab_t	*get_mnstr_tab_rand_dun_lev( long dun_lev )
+{
+	return get_mnstr_tab_rand_sub( dun_lev, TRUE );
+}
+
+/***************************************************************
+* 󥹥Υǡơ֥˸붦̽
+* long dun_lev : 󥸥γ
+* bool_t flg_no_chk_max : γؤ겼оݤȤ
+* return : 󥹥Υǡơ֥
+***************************************************************/
+
+mnstr_tab_t	*get_mnstr_tab_rand_sub(
+	long dun_lev, bool_t flg_no_chk_max
+)
 {
 	mnstr_kind_t	kind;
 	long	i, max_i, n;
@@ -1815,13 +1842,15 @@ mnstr_tab_t	*get_mnstr_tab_rand( long dun_lev )
 		if( lev_p->kind == MNSTR_KIND_NULL )
 			break;
 
-		if( lev_p->min_lev <= labs( dun_lev ) ){
-			if( labs( dun_lev ) <= lev_p->max_lev ){
-				n++;
-				if( per_randm( n ) ){
-					kind = lev_p->kind;
-				}
-			}
+		if( labs( dun_lev ) < lev_p->min_lev )
+			continue;
+		if( labs( dun_lev ) > lev_p->max_lev )
+			if( !flg_no_chk_max )
+				continue;
+
+		n++;
+		if( per_randm( n ) ){
+			kind = lev_p->kind;
 		}
 	}
 
@@ -2164,9 +2193,17 @@ bool_t	can_move_mnstr_tab( mnstr_tab_t *tab, long x, long y )
 
 mnstr_t	*get_mnstr( long x, long y )
 {
+	dun_t	*dun = get_dun();
 	mnstr_t	*head, *p, *pp;
 	pet_t	*pet;
 
+	if( !clip_pos( x, y ) )
+		return NULL;
+
+	p = dun->map.chr_p[y][x];
+	if( (p != NULL) && (p->kind == CHR_KIND_MNSTR) )
+		return p;
+
 	head = &mnstr_used;
 	for( p = head->next->next; p != NULL; p = p->next ){
 		pp = p->prev;
