@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.174 2006/09/10 23:53:46 bowkenken Exp $
+* $Id: party.c,v 1.176 2006/09/19 04:35:15 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -1412,6 +1412,31 @@ void	appear_party( void )
 
 /**/
 
+/***************************************************************
+* Сߤꤿֿ
+* return : ֿ
+***************************************************************/
+
+long	get_party_dun_max_lev( void )
+{
+	party_t	*pty = get_party();
+	long	max_lev;
+	long	i;
+
+	max_lev = 0;
+	for( i = 0; i < MBR_MAX_N; i++ ){
+		long	lev;
+
+		lev = labs( pty->mbr[i]->dun_max_lev_base );
+		if( max_lev < lev )
+			max_lev = lev;
+	}
+
+	return max_lev;
+}
+
+/**/
+
 void	scroll_center_appear_party( void )
 {
 	if( chk_flg_or( get_flg_scroll(),
@@ -2572,9 +2597,17 @@ party_t	*get_party( void )
 
 long	get_mbr_n( long x, long y )
 {
+	dun_t	*dun;
+	mbr_t	*p;
 	party_t	*pty;
 	long	n;
 
+	dun = get_dun();
+
+	p = dun->map.chr_p[y][x];
+	if( (p != NULL) && (p->kind == CHR_KIND_MBR) )
+		return( p->mbr_n );
+
 	pty = get_party();
 	for( n = 0; n < MBR_MAX_N; n++ ){
 		mbr_t	*mbr;
