@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.52 2006/08/20 12:18:10 bowkenken Exp $
+* $Id: pet.c,v 1.53 2006/09/19 04:35:15 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -420,8 +420,14 @@ pet_t	**get_ls_pet( void )
 
 pet_t	*get_pet( long x, long y )
 {
+	dun_t	*dun = get_dun();
+	pet_t	*p;
 	long	i;
 
+	p = dun->map.chr_p[y][x];
+	if( (p != NULL) && is_pet( p ) )
+		return p;
+
 	for( i = 0; i < PET_MAX_N; i++ ){
 		pet_t	*pp;
 
