@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: rumor-tab.h,v 1.5 2006/01/27 05:07:38 bowkenken Exp $
+* $Id: rumor-tab.h,v 1.6 2006/09/20 09:35:29 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	RUMOR_TAB_H
@@ -75,6 +75,16 @@ rumor_tab_t	rumor_tab[] = {
 		N_MSG_RUMOR_006_MALE,
 		TRUE, FALSE,
 	},
+	{
+		N_MSG_RUMOR_007_FEMALE,
+		N_MSG_RUMOR_007_MALE,
+		TRUE, FALSE,
+	},
+	{
+		N_MSG_RUMOR_008_FEMALE,
+		N_MSG_RUMOR_008_MALE,
+		TRUE, FALSE,
+	},
 	{
 		N_MSG_NULL,
 		N_MSG_NULL,
