@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.150 2006/09/10 23:53:46 bowkenken Exp $
+* $Id: spell.c,v 1.155 2006/09/19 02:30:57 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -250,15 +250,7 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 		return STR_MENU_ERR;
 	pre_sel_mbr = g_sel_mbr;
 
-	if( chk_flg_or( g_sel_mbr->stat,
-			FLG_STAT_NOT_EXIST
-			| FLG_STAT_DEAD
-			| FLG_STAT_STONE
-			| FLG_STAT_PARALYZE
-			| FLG_STAT_CONFUSION
-			| FLG_STAT_SLEEP
-			| FLG_STAT_SILENCE
-			) ){
+	if( !chk_can_chr_cast_stat( g_sel_mbr ) ){
 		print_msg( FLG_NULL, MSG_ERR_SPELL, g_sel_mbr->name );
 		return STR_MENU_CANCEL;
 	}
@@ -295,7 +287,7 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 		key++;
 
 		kind = (spell_kind_t)(long)(ls[i].arg);
-		if( chk_can_chr_cast( g_sel_mbr, kind ) ){
+		if( chk_can_chr_cast_lev( g_sel_mbr, kind ) ){
 			ls[i].flg &= ~FLG_MENU_HIDDEN;
 			flg_learn = TRUE;
 		} else {
@@ -461,7 +453,7 @@ char	*cb_menu_spell( menu_t **pp, menu_t **dflt )
 	if( g_sel_spell == NULL )
 		return STR_MENU_ERR;
 
-	if( !chk_can_chr_cast( g_sel_mbr, g_sel_spell->kind ) ){
+	if( !chk_can_chr_cast_lev( g_sel_mbr, g_sel_spell->kind ) ){
 		print_msg( FLG_NULL, MSG_ERR_MENU_SPELL_LEV,
 				g_sel_mbr->name );
 		return STR_MENU_CANCEL;
@@ -641,6 +633,11 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	if( tab == NULL )
 		return;
 
+	if( !chk_can_chr_cast_stat( chr ) )
+		return;
+	if( !chk_can_chr_cast_lev( chr, tab->kind ) )
+		return;
+
 	hp = tab->hp;
 	mp = tab->mp;
 	resi = tab->resi_down;
@@ -760,6 +757,8 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 		if( tab->kind != pre_tab->kind )
 			break;
 
+		/* ΤΥåϽ */
+
 		flg_msg = FALSE;
 	} while( 0 );
 
@@ -1385,7 +1384,6 @@ void	chr_cast_spell_sub(
 	long x, long y, trgt_kind_t trgt_kind, void *p
 )
 {
-	const long	turn_resi = FX_AVE_TURN_POW_UP_RESI;
 	bool_t	flg_chr;
 	chr_t	*d_p;
 
@@ -1466,7 +1464,7 @@ void	chr_cast_spell_sub(
 
 	/* ʸ뤫å */
 
-	if( !chk_spell( chr, tab, flg_item ) ){
+	if( flg_chr && !chk_spell( chr, tab, flg_item ) ){
 		curs_attrset_chr( chr, -1, FALSE );
 		print_msg( FLG_NULL, MSG_FAIL_SPELL,
 				chr->name, tab->name );
@@ -1484,6 +1482,9 @@ void	chr_cast_spell_sub(
 				d_p->name, tab->name );
 		curs_attrset_dflt();
 
+		counter_magic( chr, flg_item, tab, rate,
+				x, y, trgt_kind, d_p );
+
 		return;
 	}
 
@@ -1592,7 +1593,8 @@ void	chr_cast_spell_sub(
 		fx_std( (chr_t *)p, FX_KIND_PASSWALL );
 		break;
 	case SPELL_KIND_POLYMORPH_OTHER:
-/*@@@*/
+		fx_polymorph( (chr_t *)p );
+		break;
 	case SPELL_KIND_POLYMORPH_SELF:
 /*@@@*/
 	case SPELL_KIND_STEALTH:
@@ -1651,8 +1653,9 @@ void	chr_cast_spell_sub(
 		break;
 	case SPELL_KIND_SPELL_RESISTANCE:
 /*@@@*/
+		break;
 	case SPELL_KIND_COUNTER_MAGIC:
-/*@@@*/
+		fx_std( (chr_t *)p, FX_KIND_COUNTER_MAGIC );
 		break;
 	case SPELL_KIND_STONE:
 		fx_std( (chr_t *)p, FX_KIND_STONE );
@@ -1690,58 +1693,46 @@ void	chr_cast_spell_sub(
 	case SPELL_KIND_ENC_MIN_N:
 		break;
 	case SPELL_KIND_SHARPNESS:
-		fx_abl( (chr_t *)p, FX_KIND_SHARPNESS,
-				FX_AVE_TURN_POW_UP_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_SHARPNESS );
 		break;
 	case SPELL_KIND_STRENGTH:
-		fx_abl( (chr_t *)p, FX_KIND_STRENGTH,
-				FX_AVE_TURN_POW_UP_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_STRENGTH );
 		break;
 	case SPELL_KIND_QUICKNESS:
-		fx_abl( (chr_t *)p, FX_KIND_QUICKNESS,
-				FX_AVE_TURN_POW_UP_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_QUICKNESS );
 		break;
 	case SPELL_KIND_BRAINY:
-		fx_abl( (chr_t *)p, FX_KIND_BRAINY,
-				FX_AVE_TURN_POW_UP_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_BRAINY );
 		break;
 	case SPELL_KIND_WISE:
-		fx_abl( (chr_t *)p, FX_KIND_WISE,
-				FX_AVE_TURN_POW_UP_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_WISE );
 		break;
 	case SPELL_KIND_ATTRACTIVE:
-		fx_abl( (chr_t *)p, FX_KIND_ATTRACTIVE,
-				FX_AVE_TURN_POW_UP_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_ATTRACTIVE );
 		break;
 	case SPELL_KIND_POWER_UP_HP:
-		fx_pow_up_hp( (chr_t *)p, FX_AVE_TURN_POW_UP_HP );
+		fx_pow_up_hp( (chr_t *)p );
 		break;
 	case SPELL_KIND_HASTE:
-		fx_speed_up( chr, (chr_t *)p, +1, FX_AVE_TURN_SPEED_UP );
+		fx_speed_up( chr, (chr_t *)p, +1 );
 		break;
 	case SPELL_KIND_DULLNESS:
-		fx_abl( (chr_t *)p, FX_KIND_DULLNESS,
-				FX_AVE_TURN_POW_DOWN_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_DULLNESS );
 		break;
 	case SPELL_KIND_WEAKNESS:
-		fx_abl( (chr_t *)p, FX_KIND_WEAKNESS,
-				FX_AVE_TURN_POW_DOWN_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_WEAKNESS );
 		break;
 	case SPELL_KIND_SLOWNESS:
-		fx_abl( (chr_t *)p, FX_KIND_SLOWNESS,
-				FX_AVE_TURN_POW_DOWN_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_SLOWNESS );
 		break;
 	case SPELL_KIND_BRAINLESS:
-		fx_abl( (chr_t *)p, FX_KIND_BRAINLESS,
-				FX_AVE_TURN_POW_DOWN_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_BRAINLESS );
 		break;
 	case SPELL_KIND_FOOLISH:
-		fx_abl( (chr_t *)p, FX_KIND_FOOLISH,
-				FX_AVE_TURN_POW_DOWN_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_FOOLISH );
 		break;
 	case SPELL_KIND_UNATTRACTIVE:
-		fx_abl( (chr_t *)p, FX_KIND_UNATTRACTIVE,
-				FX_AVE_TURN_POW_DOWN_ABL );
+		fx_abl( (chr_t *)p, FX_KIND_UNATTRACTIVE );
 		break;
 	case SPELL_KIND_ENERGY_DRAIN:
 		fx_energy_drain( (chr_t *)p, FALSE );
@@ -1756,7 +1747,7 @@ void	chr_cast_spell_sub(
 
 		break;
 	case SPELL_KIND_SLOW:
-		fx_speed_up( chr, (chr_t *)p, -1, FX_AVE_TURN_SPEED_DOWN );
+		fx_speed_up( chr, (chr_t *)p, -1 );
 		break;
 	case SPELL_KIND_HUNGER:
 /*@@@*/
@@ -1874,27 +1865,27 @@ void	chr_cast_spell_sub(
 /*@@@*/
 		break;
 	case SPELL_KIND_RESIST_PHYSICAL:
-		fx_resi( (chr_t *)p, FX_KIND_RESI_KNOC, turn_resi );
-		fx_resi( (chr_t *)p, FX_KIND_RESI_SLAS, turn_resi );
-		fx_resi( (chr_t *)p, FX_KIND_RESI_STIN, turn_resi );
+		fx_resi( (chr_t *)p, FX_KIND_RESI_KNOC );
+		fx_resi( (chr_t *)p, FX_KIND_RESI_SLAS );
+		fx_resi( (chr_t *)p, FX_KIND_RESI_STIN );
 		break;
 	case SPELL_KIND_RESIST_HEAT:
-		fx_resi( (chr_t *)p, FX_KIND_RESI_HEAT, turn_resi );
+		fx_resi( (chr_t *)p, FX_KIND_RESI_HEAT );
 		break;
 	case SPELL_KIND_RESIST_COLD:
-		fx_resi( (chr_t *)p, FX_KIND_RESI_COLD, turn_resi );
+		fx_resi( (chr_t *)p, FX_KIND_RESI_COLD );
 		break;
 	case SPELL_KIND_RESIST_MIND:
-		fx_resi( (chr_t *)p, FX_KIND_RESI_MIND, turn_resi );
+		fx_resi( (chr_t *)p, FX_KIND_RESI_MIND );
 		break;
 	case SPELL_KIND_RESIST_ACID:
-		fx_resi( (chr_t *)p, FX_KIND_RESI_ACID, turn_resi );
+		fx_resi( (chr_t *)p, FX_KIND_RESI_ACID );
 		break;
 	case SPELL_KIND_RESIST_ELECTRICITY:
-		fx_resi( (chr_t *)p, FX_KIND_RESI_ELEC, turn_resi );
+		fx_resi( (chr_t *)p, FX_KIND_RESI_ELEC );
 		break;
 	case SPELL_KIND_RESIST_POISON:
-		fx_resi( (chr_t *)p, FX_KIND_RESI_POIS, turn_resi );
+		fx_resi( (chr_t *)p, FX_KIND_RESI_POIS );
 		break;
 	case SPELL_KIND_BLESS:
 		fx_bless( (chr_t *)p );
@@ -2079,6 +2070,58 @@ void	chr_cast_spell_sub(
 
 /**/
 
+void	counter_magic(
+	chr_t *chr, bool_t flg_item,
+	spell_tab_t *tab, rate_t rate,
+	long x, long y, trgt_kind_t trgt_kind, void *p
+)
+{
+	fx_t	*fx;
+	trgt_kind_t	d_trgt_kind;
+
+	if( chr == NULL )
+		return;
+	if( p == NULL )
+		return;
+
+	if( (chr->kind != CHR_KIND_MBR)
+			&& (chr->kind != CHR_KIND_MNSTR) ){
+		return;
+	}
+
+	fx = srch_fx( &(chr->fx), FX_KIND_COUNTER_MAGIC );
+	if( fx == NULL )
+		return;
+
+	switch( trgt_kind ){
+	case TRGT_KIND_MBR:
+		if( chr->kind == CHR_KIND_MBR )
+			return;
+		break;
+	case TRGT_KIND_MNSTR:
+		if( chr->kind == CHR_KIND_MNSTR )
+			return;
+		break;
+	default:
+		return;
+	}
+
+	g_vfx_n = 1;
+	g_vfx_bgn[0].x = x * 2;
+	g_vfx_bgn[0].y = y;
+	g_vfx_end[0].x = chr->x * 2;
+	g_vfx_end[0].y = chr->y;
+	if( trgt_kind != TRGT_KIND_NULL )
+		vfx_spell( tab, g_vfx_n, g_vfx_bgn, g_vfx_end );
+
+	d_trgt_kind = get_trgt_kind_from_chr( chr );
+
+	chr_cast_spell_sub( chr, flg_item, tab, rate,
+			chr->x, chr->y, d_trgt_kind, chr );
+}
+
+/**/
+
 bool_t	chk_spell( chr_t *o_p, spell_tab_t *tab, bool_t flg_item )
 {
 	abl_kind_t	o_abl, o_sub_abl;
@@ -2106,8 +2149,10 @@ bool_t	chk_spell( chr_t *o_p, spell_tab_t *tab, bool_t flg_item )
 
 	/* ˤ뽤 */
 
-	rate *= calc_rate_equip( o_p, o_abl, o_sub_abl );
-	rate /= _100_PERCENT;
+	if( o_p->kind != CHR_KIND_NULL ){
+		rate *= calc_rate_equip( o_p, o_abl, o_sub_abl );
+		rate /= _100_PERCENT;
+	}
 
 	print_msg_find( o_p, FLG_MSG_DEBUG,
 			"chk_spell() rate %ld", rate );
@@ -2458,7 +2503,29 @@ bool_t	chk_bar_limit_lev( chr_t *chr )
 
 /**/
 
-bool_t	chk_can_chr_cast( chr_t *chr, spell_kind_t kind )
+bool_t	chk_can_chr_cast_stat( chr_t *chr )
+{
+	if( chr == NULL )
+		return FALSE;
+
+	if( chk_flg_or( chr->stat,
+			FLG_STAT_NOT_EXIST
+			| FLG_STAT_DEAD
+			| FLG_STAT_STONE
+			| FLG_STAT_PARALYZE
+			| FLG_STAT_CONFUSION
+			| FLG_STAT_SLEEP
+			| FLG_STAT_SILENCE
+			) ){
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+/**/
+
+bool_t	chk_can_chr_cast_lev( chr_t *chr, spell_kind_t kind )
 {
 	spell_tab_t	*spell_tab;
 
