@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu.c,v 1.103 2006/09/10 23:53:46 bowkenken Exp $
+* $Id: tmenu.c,v 1.104 2006/09/26 18:12:20 bowkenken Exp $
 ***************************************************************/
 
 #define	TMENU_C
@@ -355,7 +355,7 @@ char	*cb_menu_temple_contribution( menu_t **pp, menu_t **dflt )
 	spell_price = get_price_temple_contribution( g_sel_mbr );
 	price = spell_price;
 
-	str_goto = exec_menu_sel_num( 1, g_sel_mbr->gold, &price );
+	str_goto = exec_menu_sel_num( &price, 1, g_sel_mbr->gold );
 	if( str_goto != NULL )
 		return str_goto;
 
