@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.h,v 1.20 2006/01/15 15:16:09 bowkenken Exp $
+* $Id: town.h,v 1.21 2006/02/24 14:39:37 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TOWN_H
@@ -35,6 +35,9 @@
 #include	"party.h"
 #include	"mnstr.h"
 
+#define	SHOP_ADD_TURN_N	(15 * TURN_PER_MINUTE)
+#define	NAVI_ADD_TURN_N	((MAP_MAX_X + MAP_MAX_Y) / 2)
+
 typedef enum {
 	SHOP_N_NULL,
 	SHOP_N_BAR,
