@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: trap.c,v 1.57 2006/09/15 09:38:44 bowkenken Exp $
+* $Id: trap.c,v 1.59 2006/09/19 05:13:32 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -57,6 +57,8 @@
 #define	PIT_DAM_RATE	((rate_t)25)
 #define	PIT_DAM_ADD	1
 
+/* 櫤ǽͤΥ٥ */
+
 /***************************************************************
 * Хѿ
 ***************************************************************/
@@ -534,6 +536,8 @@ void	chk_trap( chr_t *chr, chr_t *thief )
 
 	if( dun->map.obj.mjr[chr->y][chr->x] != FACE_MJR_TRAP )
 		return;
+	if( dun->map.obj.mnr[chr->y][chr->x] == FACE_MNR_TRAP_SANCTUARY )
+		return;
 
 	trap = get_trap( chr->x, chr->y );
 	if( trap == NULL )
@@ -584,6 +588,9 @@ void	find_trap( trap_t *trap )
 
 void	caught_trap( trap_t *trap, chr_t *chr )
 {
+	long	lev;
+	long	i;
+
 	if( trap == NULL )
 		return;
 	if( trap->tab == NULL )
@@ -617,6 +624,15 @@ void	caught_trap( trap_t *trap, chr_t *chr )
 	g_dmy_chr.trgt.true_x = g_dmy_chr.trgt.x;
 	g_dmy_chr.trgt.true_y = g_dmy_chr.trgt.y;
 	g_dmy_chr.trgt.p = chr;
+	g_dmy_chr.flg_chr = FLG_NULL;
+	g_dmy_chr.flg_map = FLG_NULL;
+	g_dmy_chr.attitude = ATTITUDE_ENEMY;
+	lev = calc_trap_lev( trap );
+	for( i = 0; i < ABL_KIND_MAX_N; i++ ){
+		g_dmy_chr.abl.lev[i].n = lev;
+		g_dmy_chr.abl.lev[i].max = lev;
+		g_dmy_chr.abl.lev[i].add = 0;
+	}
 
 	switch( trap->kind ){
 	case TRAP_KIND_NULL:
@@ -727,6 +743,9 @@ void	caught_trap_pit( chr_t *chr )
 {
 	long	dam;
 
+	if( chr == NULL )
+		return;
+
 	dam = calc_max_hp( chr ) * PIT_DAM_RATE / _100_PERCENT;
 	dam += PIT_DAM_ADD;
 
@@ -840,6 +859,27 @@ bool_t	chk_map_sanctuary( long x, long y )
 	return TRUE;
 }
 
+/***************************************************************
+* 櫤ǽͤΥ٥׻
+* trap_t *p : 
+* return : 櫤ǽͤΥ٥
+***************************************************************/
+
+long	calc_trap_lev( trap_t *p )
+{
+	long	lev;
+
+	if( p == NULL )
+		return 1;
+
+	lev = labs( p->lev ) * RATE_LEV_PER_DUN_LEV / _100_PERCENT;
+
+	if( lev < 1 )
+		lev = 1;
+
+	return lev;
+}
+
 /***************************************************************
 * 櫤ꥹȤ˥󥯤
 * trap_t *ls : 櫤Υꥹ
